@@ -4,9 +4,12 @@
     
     chk <- unlist(strsplit(ent.str, split=""))
     
-    if(ent.typ == "real") accept.vals <- c(as.character(0:9), ".", "-")
-    if(ent.typ == "second") accept.vals <- c(as.character(0:9), ".")
-    if(ent.typ %in% c("integer", "hour", "minute")) accept.vals <- c(as.character(0:9))
+    if(ent.typ == "real") 
+        accept.vals <- c(as.character(0:9), ".", "-")
+    if(ent.typ == "second") 
+        accept.vals <- c(as.character(0:9), ".")
+    if(ent.typ %in% c("integer", "hour", "minute")) 
+        accept.vals <- c(as.character(0:9))
     if(ent.typ == "date") {
         accept.vals <- c("a", "A", "b", "c", "C", "d", "D", "e", "E", "F", "g", "G", "h", "H", 
                        "I", "j", "k", "l", "m", "M", "n", "O", "p", "r", "R", "S", "t", "T", 
@@ -21,10 +24,8 @@
     
     if(ent.typ == "hour" & ans != "") 
         if(as.integer(ans) > 23) ans <- "23"
-    
     if(ent.typ == "minute" & ans != "") 
         if(as.integer(ans) > 59) ans <- "59"
-    
     if(ent.typ == "second" & ans != "") {
         if(as.real(ans) < 0) ans <- "0"
         if(as.real(ans) > 59.999) ans <- "59.999"
